@@ -126,6 +126,11 @@ func newHcsTask(
 	owner := filepath.Base(os.Args[0])
 	isTemplate := oci.ParseAnnotationsSaveAsTemplate(ctx, s)
 
+	io, err := cmd.NewUpstreamIO(ctx, req.ID, req.Stdout, req.Stderr, req.Stdin, req.Terminal)
+	if err != nil {
+		return nil, err
+	}
+
 	var netNS string
 	if s.Windows != nil &&
 		s.Windows.Network != nil {
@@ -148,16 +153,9 @@ func newHcsTask(
 		HostingSystem:    parent,
 		NetworkNamespace: netNS,
 	}
-	// Default to an infinite timeout (zero value)
-	var ioRetryTimeout time.Duration
+
 	if shimOpts != nil {
 		opts.ScaleCPULimitsToSandbox = shimOpts.ScaleCpuLimitsToSandbox
-		ioRetryTimeout = time.Duration(shimOpts.IoRetryTimeoutInSec) * time.Second
-	}
-
-	io, err := cmd.NewUpstreamIO(ctx, req.ID, req.Stdout, req.Stderr, req.Stdin, req.Terminal, ioRetryTimeout)
-	if err != nil {
-		return nil, err
 	}
 
 	system, resources, err := hcsoci.CreateContainer(ctx, &opts)
@@ -166,17 +164,16 @@ func newHcsTask(
 	}
 
 	ht := &hcsTask{
-		events:         events,
-		id:             req.ID,
-		isWCOW:         oci.IsWCOW(s),
-		c:              system,
-		cr:             resources,
-		ownsHost:       ownsParent,
-		host:           parent,
-		closed:         make(chan struct{}),
-		taskSpec:       s,
-		isTemplate:     isTemplate,
-		ioRetryTimeout: ioRetryTimeout,
+		events:     events,
+		id:         req.ID,
+		isWCOW:     oci.IsWCOW(s),
+		c:          system,
+		cr:         resources,
+		ownsHost:   ownsParent,
+		host:       parent,
+		closed:     make(chan struct{}),
+		taskSpec:   s,
+		isTemplate: isTemplate,
 	}
 	ht.init = newHcsExec(
 		ctx,
@@ -254,21 +251,7 @@ func newClonedHcsTask(
 		return nil, fmt.Errorf("cloned task can only be created inside a windows host")
 	}
 
-	var shimOpts *runhcsopts.Options
-	if req.Options != nil {
-		v, err := typeurl.UnmarshalAny(req.Options)
-		if err != nil {
-			return nil, err
-		}
-		shimOpts = v.(*runhcsopts.Options)
-	}
-
-	// Default to an infinite timeout (zero value)
-	var ioRetryTimeout time.Duration
-	if shimOpts != nil {
-		ioRetryTimeout = time.Duration(shimOpts.IoRetryTimeoutInSec) * time.Second
-	}
-	io, err := cmd.NewNpipeIO(ctx, req.Stdin, req.Stdout, req.Stderr, req.Terminal, ioRetryTimeout)
+	io, err := cmd.NewNpipeIO(ctx, req.Stdin, req.Stdout, req.Stderr, req.Terminal)
 	if err != nil {
 		return nil, err
 	}
@@ -422,9 +405,6 @@ type hcsTask struct {
 
 	// taskSpec represents the spec/configuration for this task.
 	taskSpec *specs.Spec
-
-	// ioRetryTimeout is the time for how long to try reconnecting to stdio pipes from containerd.
-	ioRetryTimeout time.Duration
 }
 
 func (ht *hcsTask) ID() string {
@@ -445,7 +425,7 @@ func (ht *hcsTask) CreateExec(ctx context.Context, req *task.ExecProcessRequest,
 		return errors.Wrapf(errdefs.ErrFailedPrecondition, "exec: '' in task: '%s' must be running to create additional execs", ht.id)
 	}
 
-	io, err := cmd.NewUpstreamIO(ctx, req.ID, req.Stdout, req.Stderr, req.Stdin, req.Terminal, ht.ioRetryTimeout)
+	io, err := cmd.NewUpstreamIO(ctx, req.ID, req.Stdout, req.Stderr, req.Stdin, req.Terminal)
 	if err != nil {
 		return err
 	}
